@@ -54,7 +54,10 @@ on_exit() {
   properties=$(dx describe ${DX_JOB_ID} --json 2>/dev/null | jq -r ".properties")
   if [[ $properties != "null" ]]; then
     if [[ $(jq .nextflow_errorStrategy <<<${properties} -r) == "ignore" ]]; then
-      echo "ignore had happened"
+      ignored_subjobs=$(jq .nextflow_errored_subjobs <<<${properties} -r)
+      if [[ ${ignored_subjobs} != "null" ]]; then
+        echo "Subjob(s) ${ignored_subjobs} ran into Nextflow process errors. \"ignore\" errorStrategy was applied."
+      fi
     fi
   fi
   set +x
@@ -277,7 +280,7 @@ main() {
   fi
 
   DX_CACHEDIR=$DX_PROJECT_CONTEXT_ID:/.nextflow_cache_db
-  NXF_PLUGINS_VERSION=1.3.1
+  NXF_PLUGINS_VERSION=1.4.0
 
   # check if all run opts provided by user are supported
   validate_run_opts
@@ -406,6 +409,17 @@ nf_task_exit() {
   # mark the job as successful in any case, real task
   # error code is managed by nextflow via .exitcode file
   if [ -z ${exit_code} ]; then export exit_code=0; fi
+
+  # Make sure that subjob with errorStrategy == terminate end in 'failed' state
+  terminate_record=$(dx find data --name $DX_JOB_ID --path $DX_WORKSPACE_ID --brief | head -n 1)
+  if [ "$exit_code" -ne "0" ] && [ -n "${terminate_record}" ]; then
+    echo "Subjob exited with non-zero exit_code and the errorStrategy is terminate."
+    echo "Waiting for the headjob to kill the job tree..."
+    sleep 240
+    echo "This subjob was not killed in time, exiting to prevent excessive waiting."
+    exit
+  fi
+
   dx-jobutil-add-output exit_code $exit_code --class=int
 }
 
