@@ -40,7 +40,7 @@ else:
     spawn_extra_args = {"encoding": "utf-8"}
 
 
-default_input_len = 5
+default_input_len = 7
 input1 = {
     "class": "file",
     "name": "first_input",
@@ -54,6 +54,18 @@ input2 = {
     "help": "second input",
     "label": "Test2"
 }
+input3 = {
+    "class": "file",
+    "name": "third_input",
+    "help": "(Nextflow pipeline optional)third input",
+    "label": "Test3"
+}
+input4 = {
+    "class": "file",
+    "name": "fourth_input",
+    "help": "(Nextflow pipeline required)fourth input",
+    "label": "Test4"
+}
 
 
 class TestNextflowTemplates(DXTestCase):
@@ -87,21 +99,49 @@ class TestNextflowTemplates(DXTestCase):
         self.assertEqual(len(dxapp.get("inputSpec")),
                          default_input_len + len(inputs))
 
+    @unittest.skipIf(USING_PYTHON2,
+        'Skipping as the Nextflow template from which applets are built is for Py3 interpreter only')
     def test_src_basic(self):
         src = get_nextflow_src()
         self.assertTrue("#!/usr/bin/env bash" in src)
         self.assertTrue("nextflow" in src)
 
+    @unittest.skipIf(USING_PYTHON2,
+        'Skipping as the Nextflow template from which applets are built is for Py3 interpreter only')
     def test_src_profile(self):
         src = get_nextflow_src(profile="test_profile")
         self.assertTrue("-profile test_profile" in src)
 
+    @unittest.skipIf(USING_PYTHON2,
+        'Skipping as the Nextflow template from which applets are built is for Py3 interpreter only')
     def test_src_inputs(self):
-        src = get_nextflow_src(custom_inputs=[input1, input2])
-        self.assertTrue("if [ -n \"${}\" ];".format(input2.get("name")) in src)
-        self.assertTrue("--{}=${}".format(input2.get("name"), input2.get("name")))
+        '''
+        Tests that code that handles custom nextflow input parameters (e.g. from nextflow schema) with different classes
+        are properly added in the applet source script. These input arguments should be
+        1) appended to nextflow cmd as runtime parameters
+        2) added to runtime configuration nxf_runtime.config if it is an optional param in nextflow_schema
+        '''
+        src = get_nextflow_src(custom_inputs=[input1, input2, input3, input4])
+        # case 1: file input, need to convert from dnanexus link to its file path inside job workspace
         self.assertTrue("if [ -n \"${}\" ];".format(input1.get("name")) in src)
-        self.assertTrue("--{}=${}".format(input1.get("name"), input1.get("name")))
+        value1 = 'dx://${DX_WORKSPACE_ID}:/$(echo ${%s} | jq .[$dnanexus_link] -r | xargs -I {} dx describe {} --json | jq -r .name)' % input1.get(
+            "name")
+        self.assertTrue("--{}={}".format(input1.get("name"), value1) in src)
+        # case 2: string input, need no conversion
+        self.assertTrue("if [ -n \"${}\" ];".format(input2.get("name")) in src)
+        value2 = '${%s}' % input2.get("name")
+        self.assertTrue("--{}={}".format(input2.get("name"), value2) in src)
+        # case 3: file input (nextflow pipeline optional), added to nxf_runtime.config
+        self.assertTrue("if [ -n \"${}\" ];".format(input3.get("name")) in src)
+        value3 = '\\"dx://${DX_WORKSPACE_ID}:/$(echo ${%s} | jq .[$dnanexus_link] -r | xargs -I {} dx describe {} --json | jq -r .name)\\"' % input3.get(
+            "name")
+        self.assertTrue("echo params.{}={} >> nxf_runtime.config".format(
+            input3.get("name"), value3) in src)
+        # case 4: file input (nextflow pipeline required), same as case 1
+        self.assertTrue("if [ -n \"${}\" ];".format(input4.get("name")) in src)
+        value4 = 'dx://${DX_WORKSPACE_ID}:/$(echo ${%s} | jq .[$dnanexus_link] -r | xargs -I {} dx describe {} --json | jq -r .name)' % input4.get(
+            "name")
+        self.assertTrue("--{}={}".format(input4.get("name"), value4) in src)
 
     def test_prepare_inputs(self):
         inputs = prepare_custom_inputs(schema_file="./nextflow/schema2.json")
@@ -215,6 +255,20 @@ class TestDXBuildNextflowApplet(DXTestCaseBuildNextflowApps):
         details = applet.get_details()
         self.assertEqual(details["repository"], hello_repo_url)
 
+    @unittest.skipUnless(testutil.TEST_RUN_JOBS,
+                         'skipping tests that would run jobs')
+    def test_dx_build_nextflow_from_repository_destination(self):
+        hello_repo_url = "https://github.com/nextflow-io/hello"
+        folder = "/test_dx_build_nextflow_from_repository_destination/{}".format(str(uuid.uuid4().hex))
+        run("dx mkdir -p {}".format(folder))
+        applet_json = run(
+            "dx build --nextflow --repository '{}' --brief --destination {}".format(hello_repo_url, folder)).strip()
+        applet_id = json.loads(applet_json).get("id")
+
+        applet = dxpy.DXApplet(applet_id)
+        desc = applet.describe()
+        self.assertEqual(desc["folder"], folder)
+
     @unittest.skipUnless(testutil.TEST_RUN_JOBS,
                          'skipping tests that would run jobs')
     def test_dx_build_nextflow_from_repository_with_extra_args(self):
@@ -260,8 +314,8 @@ class TestDXBuildNextflowApplet(DXTestCaseBuildNextflowApps):
         print(job_desc["output"])
         self.assertEqual(len(job_desc["output"]["nextflow_log"]), 1)
 
-        # the output files will be: nxf_runtime.config, ls_folder.txt, cat_file.txt
-        self.assertEqual(len(job_desc["output"]["output_files"]), 3)
+        # the output files will be: ls_folder.txt, cat_file.txt
+        self.assertEqual(len(job_desc["output"]["published_files"]), 2)
 
     def test_dx_build_nextflow_with_destination(self):
         pipeline_name = "hello"
@@ -296,6 +350,23 @@ class TestRunNextflowApplet(DXTestCaseBuildNextflowApps):
         # are not printed
         self.assertNotIn("Launching", watched_run_output)
 
+    # @unittest.skipUnless(testutil.TEST_RUN_JOBS,
+    #                      'skipping tests that would run jobs')
+    # def test_dx_run_nextflow_with_unsupported_runtime_opts(self):
+    #     pipeline_name = "hello"
+    #     applet_dir = self.write_nextflow_applet_directory(pipeline_name, existing_nf_file_path=self.base_nextflow_nf)
+    #     applet_id = json.loads(run("dx build --nextflow --json " + applet_dir))["id"]
+    #     applet = dxpy.DXApplet(applet_id)
+
+    #     job = applet.run({
+    #                      "nextflow_run_opts": "-w user_workdir",
+    #     })
+        
+    #     job.wait_on_done()
+    #     job_desc = dxpy.describe(job.get_id())
+    #     self.assertEqual(job_desc["failureReason"], "AppError")
+    #     self.assertIn("Please remove workDir specification", job_desc["failureMessage"])
+
 if __name__ == '__main__':
     if 'DXTEST_FULL' not in os.environ:
         sys.stderr.write(
